@@ -25,25 +25,27 @@ import math
 #from math import exp, sqrt, pi, log
 from decimal import Decimal, getcontext
 from scipy.stats import norm
+# from scipy.special import erf as errorfunction
 
 def erf(x):
-    ## error function approximation with an error less than 1.5 * 10-7 for all x
-    # save the sign of x
-    sign = 1 if x >= 0 else -1
-    x = abs(x)
+    return math.erf(x)
+    # ## error function approximation with an error less than 1.5 * 10-7 for all x
+    # # save the sign of x
+    # sign = 1 if x >= 0 else -1
+    # x = abs(x)
 
-    # constants
-    a1 = 0.254829592
-    a2 = -0.284496736
-    a3 = 1.421413741
-    a4 = -1.453152027
-    a5 = 1.061405429
-    p = 0.3275911
+    # # constants
+    # a1 = 0.254829592
+    # a2 = -0.284496736
+    # a3 = 1.421413741
+    # a4 = -1.453152027
+    # a5 = 1.061405429
+    # p = 0.3275911
 
-    # A&S formula 7.1.26
-    t = 1.0 / (1.0 + p * x)
-    y = 1.0 - (((((a5 * t + a4) * t) + a3) * t + a2) * t + a1) * t * math.exp(-x * x)
-    return sign * y # erf(-x) = -erf(x)
+    # # A&S formula 7.1.26
+    # t = 1.0 / (1.0 + p * x)
+    # y = 1.0 - (((((a5 * t + a4) * t) + a3) * t + a2) * t + a1) * t * math.exp(-x * x)
+    # return sign * y # erf(-x) = -erf(x)
 
 def erfcc(x):
     """Complementary error function."""
